package com.simonstl.fragment;

import org.xml.sax.SAXException;


/*
The contents of this file are subject to the Mozilla Public License  Version 1.1 (the "License"); you may not use this file except in  compliance with the License. You may obtain a copy of the License at 
http://www.mozilla.org/MPL/ 
Software distributed under the License is distributed on an "AS IS"  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the  License for the specific language governing rights and limitations under  the License. 

The Original Code is available at  http://simonstl.com/projects/fragment/original. 

The Initial Developer of the Original Code is Simon St.Laurent. Portions  created by Simon St.Laurent are Copyright (C) 2001. All Rights Reserved. 

Contributor(s): 
*/

/**
* <p>The DocComponent abstract class stores information about XML document components in a way which makes it easy
* use them in a streaming SAX environment.</p>
*
* <p>Version 0.04 removes the <code>isAttribute</code> property and <code>getIsAttribute()</code> method.</p>
*
* <p>Version 0.03 adds the <code>cleanDuplicate()</code> method.</p>
*
* <p>Version 0.02 adds the boolean <code>isAttribute</code> and the <code>getIsAttribute()</code> method.</p>
*
* <p>version 0.01 is the initial release, based on version 0.05 of the Element class.</p>
*
* @version 0.04 5 July 2001
* @author Simon St.Laurent
*/

public abstract class DocComponent implements Cloneable{
    protected String nsURI=null;
    protected String localName=null;;
    protected String prefix=null;;
    protected String content=null;
    protected String before=null;
    protected String after=null;
    protected String type=null;


/**
* Takes a string representing a component description and returns true or false to indicate
* whether or not it matches this component.
**/
public abstract boolean matchComponent (String match);

/**
* Returns a key which can be used as a unique identifier for this component.
**/
public abstract String getKey();

/**
* Accepts a URI reference value which is used as the namespace for the component.
**/
public void setNsURI(String newNsURI) {
      nsURI=newNsURI;
}

/**
* Returns the URI reference value for the namespace.
**/
public String getNsURI() {
      return nsURI;
}

/**
* Accepts a string which will serve as the local name for this component.
**/
public void setLocalName(String newLocalName) {
      localName=newLocalName;
}

/**
* Returns the local name for the component
**/
public String getLocalName() {
      return localName;
}

/**
* Accepts a string which serves as the prefix for this component.
**/
public void setPrefix(String newPrefix) {
      prefix=newPrefix;
}

/**
* Returns the prefix used to represent the namespace URI reference for this component.
**/
public String getPrefix() {
      return prefix;
}

/**
* Sets the content for this component.
**/
public void setContent(String newContent) {
      content=newContent;
}

/**
* Sets the content for this component.
**/
public void addContent(DocComponent newComponent) {
      content=newComponent.getContent();
}

/**
* Clears the content for this component.
**/
public void clearContent() {
      content=null;
}

/**
* Returns the content for this component.
**/
public String getContent() {
      return content;
}
/**
* Sets a string of content which may appear before the component
**/
public void setBefore(String newBefore) {
      before=newBefore;
}
/**
* Returns a string of content which may appear before the component
**/

public String getBefore() {
      return before;
}

/**
* Sets a string of content which may appear after the component
**/
public void setAfter(String newAfter) {
      after=newAfter;
}

/**
* Returns a string of content which may appear after the component
**/
public String getAfter() {
      return after;
}

/**
* Sets the type for this component.  CDATA is typical for attributes, but may be used for others.
**/
public String getType() {
    return type;
}

/**
* Gets the type for this component.  CDATA is typical for attributes, but may be used for others.
**/

public void setType(String _type) {
    type=_type;
}


/**
* Describes the content for this component as a series of SAX events.  Note that {@link com.simonstl.fragment.FragmentFilter FragmentFilter} supports some events (startChars and endChars) which
* are extensions to the existing SAX models and which serve to keep the stacks under control.
**/
public abstract void eventComponent(FragmentFilter handler) throws SAXException;



/**
* Prints a representation of the component to STDOUT
**/
public abstract void print() ;

/**
* Returns a representation of the component as a String.
**/
public abstract String toString() ;

/**
* Supports processing of content, if any.  By default, does nothing. (Element overrides, Attribute will.)
**/
public void processComponentContent (FragmentRules rules) {
}

/**
* Returns a clean copy of the component and its contents.
**/
public abstract DocComponent cleanDuplicate() ;

/**
* This method is here to provide clone-ability. Replaced by cleanDuplicate().
**/
public Object clone() {
  Object o=null;
  try {
    o=super.clone();
  } catch (CloneNotSupportedException e) {
    System.out.println("DocComponent can't clone!");
  }
  return o;
}

}